@@ -28,14 +28,16 @@
  *----------------------------------------------------------------------------*/
 #include <string.h>
 
+#include "muse_idp.h"
+
 #include "muse_dfs.h"
 #include "muse_pfits.h"
+#include "muse_rtcdata.h"
 #include "muse_pixtable.h"
 #include "muse_cplwrappers.h"
 #include "muse_wcs.h"
 #include "muse_flux.h"
 #include "muse_utils.h"
-#include "muse_idp.h"
 
 /*----------------------------------------------------------------------------*
  *                              Defines                                       *
@@ -83,9 +85,9 @@
 #define KEY_WAVELMAX                 "WAVELMAX"
 #define KEY_WAVELMAX_COMMENT         "[nm] Maximum wavelength"
 #define KEY_SKY_RES                  "SKY_RES"
-#define KEY_SKY_RES_COMMENT          "[arcsec] FWHM effective spatial resolution (measured)"
+#define KEY_SKY_RES_COMMENT          "[arcsec] FWHM effective spatial resolution"
 #define KEY_SKY_RERR                 "SKY_RERR"
-#define KEY_SKY_RERR_COMMENT         "[arcsec] Error of SKY_RES (estimated)"
+#define KEY_SKY_RERR_COMMENT         "[arcsec] Error of SKY_RES"
 #define KEY_SPEC_RES                 "SPEC_RES"
 #define KEY_SPEC_RES_COMMENT         "Spectral resolving power at central wavelength"
 #define KEY_SPEC_ERR                 "CRDER3"
@@ -206,11 +208,13 @@ static const double kMuseResponseRef = 41.2;
 /* Typical error estimated from unresolved sources [arcsec] */
 static const double kMuseExtraErrorIQE = 0.3;
 
-/* Typical values [arcsec] for the effective spatial resolution */
-/* and its uncertainty, given by the median and the standard    */
-/* deviation of previous measurements.                          */
-static const double kMuseSkyRes      = 0.853823;
-static const double kMuseSkyResError = 0.495547;
+/* Typical values [arcsec] for the effective spatial resolution *
+ * and its uncertainty, given by the median and the standard    *
+ * deviation of previous measurements.                          */
+static const double kMuseSkyResWFM      = 0.853823;
+static const double kMuseSkyResErrorWFM = 0.495547;
+static const double kMuseSkyResNFM      = 0.15;
+static const double kMuseSkyResErrorNFM = 0.05;
 
 
 /* Unit conversion factors */
@@ -394,6 +398,54 @@ muse_idp_compute_iqe(double aLambda, double aSeeing, double aAirmass)
   return iqe;
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @private
+  @brief Compute the effective spatial resolution from the Strehl ratio.
+  @param aSkyres      Computed effective spatial resolution.
+  @param aSkyresError Error of the computed effective spatial resolution.
+  @param aStrehl      Strehl ratio to convert.
+  @param aStrehlError Error of the Strehl ratio.
+  @return Nothing.
+
+  Converts the given input Strehl ratio into an effective spatial resolution
+  valid for a MUSE NFM observation. The conversion uses an empirical model
+  which is only valid for the MUSE NFM mode!
+
+  The computed spatial resolution and its uncertainty are stored at the
+  location referenced by @em aSkyres and @em aSkyresError.
+ */
+/*----------------------------------------------------------------------------*/
+static void
+muse_idp_compute_skyres_from_strehl(double *aSkyres, double *aSkyresError,
+                                    double aStrehl, double aStrehlError)
+{
+  /* Parameter values of the empirically determined model used to convert *
+   * a Strehl ratio into an effective spatial resolution for the NFM      *
+   * instrument mode.                                                     */
+  const double rms = 0.01;
+  const double parameter[3] = {-0.71985411, 0.81622807, -0.01941496};
+
+  const double strehl_min = 1.;
+  const double strehl_max = 80.;
+
+  /* The uncertainty of the Strehl ratio is actually not used in the *
+   * following model implementation. Keep it to be prepared.         */
+  CPL_UNUSED(aStrehlError);
+
+  /* Keep the input strehl ratio to the model within the limits */
+  double strehl = CPL_MIN(CPL_MAX(aStrehl, strehl_min), strehl_max);
+
+  double skyres = parameter[0] + parameter[1] * pow(strehl, parameter[2]);
+  double skyrerr = parameter[1] * parameter[2] *
+      pow(strehl, (parameter[2] - 1.));
+  skyrerr = sqrt(skyrerr * skyrerr + rms * rms);
+
+  *aSkyres = skyres;
+  *aSkyresError = skyrerr;
+  return;
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @private
@@ -853,7 +905,7 @@ muse_idp_properties_collect(muse_processing *aProcessing,
           cpl_errorstate_set(_status);
       }
 
-      double iqe    = kMuseSkyRes;
+      double iqe    = kMuseSkyResWFM;
       double fwhmIA = muse_pfits_get_ia_fwhmlin(_header);
 
       if (cpl_errorstate_is_equal(_status)) {
@@ -993,25 +1045,60 @@ muse_idp_properties_collect(muse_processing *aProcessing,
     }
   }
 
-  /* Compute product image quality estimate and its uncertainty */
-  properties->skyres /= properties->texptime;
-  if ((fwhmmin > 0.) && (fwhmmax > 0.)) {
-      properties->skyrerr = 0.5 * fabs(fwhmmax - fwhmmin);
-      properties->skyrerr = sqrt(properties->skyrerr * properties->skyrerr +
-                                 kMuseExtraErrorIQE * kMuseExtraErrorIQE);
-  } else {
-      cpl_msg_warning(__func__, "Got invalid seeing information! Using an "
-                      "estimate for \"SKY_RERR\"!");
-      properties->skyrerr = kMuseSkyResError;
-  }
+  const cpl_propertylist *header = aCube->header;
+  const char *insmode = muse_pfits_get_insmode(header);
 
+  /* Compute product image quality estimate and its uncertainty depending   *
+   * on the instruments mode. Initialize the quality measurements using the *
+   * negative guess values. This allows to validate later whether the       *
+   * quantity was actually measured or is a default.                        */
+
+  /* XXX: A better way to propagate the "measurement method" would be to     *
+   *      propagate it explicitly, for instance in the properties structure. *
+   *      Formally this is an interface change! Therefore this workaround of *
+   *      using the sign is used here.                                       */
+  if (insmode) {
+    if (strncmp(insmode, "NFM", 3) ==  0) {
+      properties->skyres = -kMuseSkyResNFM;
+      properties->skyrerr = -kMuseSkyResErrorNFM;
+
+      cpl_errorstate estate = cpl_errorstate_get();
+      double strehl = cpl_propertylist_get_double(header,
+                                                  MUSE_HDR_RTC_STREHL);
+      double strehlerr = cpl_propertylist_get_double(header,
+                                                     MUSE_HDR_RTC_STREHLERR);
+      if (cpl_errorstate_is_equal(estate)) {
+        muse_idp_compute_skyres_from_strehl(&properties->skyres,
+                                            &properties->skyrerr,
+                                            strehl, strehlerr);
+      } else {
+        cpl_errorstate_set(estate);
+        cpl_msg_warning(__func__, "No RTC Strehl ratio measurements are "
+                        "available. Using default estimates for \"SKY_RES\" "
+                        "and \"SKY_RERR\"!");
+      }
+    } else {
+      properties->skyres /= properties->texptime;
+      if ((fwhmmin > 0.) && (fwhmmax > 0.)) {
+          properties->skyrerr = 0.5 * fabs(fwhmmax - fwhmmin);
+          properties->skyrerr = sqrt(properties->skyrerr * properties->skyrerr +
+                                     kMuseExtraErrorIQE * kMuseExtraErrorIQE);
+      } else {
+          cpl_msg_warning(__func__, "Got invalid seeing information! Using an "
+                          "estimate for \"SKY_RERR\"!");
+          properties->skyrerr = -kMuseSkyResErrorWFM;
+      }
+    }
+  } else {
+    cpl_msg_error(__func__, "Cannot get instrument mode from the data cube!");
+    muse_idp_properties_delete(properties);
+    return NULL;
+  }
 
   /* Collect data from the product header. */
 
   cpl_msg_debug(__func__, "Collecting IDP data from products");
 
-  const cpl_propertylist *header = aCube->header;
-
   /* Get FOV center coordinates and the limits of wavelength range. */
   cpl_wcs *wcs = cpl_wcs_new_from_propertylist(header);
   int naxes = cpl_wcs_get_image_naxis(wcs);
@@ -1051,7 +1138,6 @@ muse_idp_properties_collect(muse_processing *aProcessing,
   /* Estimate the spectral resolution at the wavelength range center */
   const muse_specres_lut_entry *specres_data = muse_specres_data_wfm;
 
-  const char *insmode = muse_pfits_get_insmode(header);
   if (strncmp(insmode, "NFM", 3) ==  0) {
     specres_data = muse_specres_data_nfm;
   }
@@ -1115,11 +1201,13 @@ muse_idp_properties_collect(muse_processing *aProcessing,
   }
 
   status = cpl_errorstate_get();
+  /* Use the absolute value of the skyres quantity, an negative value just *
+   * indicates that it is a default rather than a measured value.          */
   double abmaglimit =
       muse_idp_compute_abmaglimit(aCube,
                                   properties->wlenrange[0] * nm2Angstrom,
                                   properties->wlenrange[1] * nm2Angstrom,
-                                  properties->skyres / CPL_MAX(xscale, yscale));
+                                  fabs(properties->skyres) / CPL_MAX(xscale, yscale));
   if (!cpl_errorstate_is_equal(status)) {
     properties->abmaglimit = -99.;
     cpl_errorstate_set(status);
@@ -1303,12 +1391,28 @@ muse_idp_properties_update(cpl_propertylist *aHeader,
   cpl_propertylist_insert_after_double(aHeader, KEY_WAVELMAX, KEY_SPEC_RES,
                                        aProperties->specres);
   cpl_propertylist_set_comment(aHeader, KEY_SPEC_RES, KEY_SPEC_RES_COMMENT);
+
+  /* If any of the properties 'skyres' and 'skyrerr' is negative, the value *
+   * is a default rather than a measured quantity. Indicate this in the     *
+   * comment. The actual value to be written to the header is the absolute  *
+   * value of the quantity.                                                 */
   cpl_propertylist_insert_after_double(aHeader, KEY_SPEC_RES, KEY_SKY_RES,
-                                       aProperties->skyres);
-  cpl_propertylist_set_comment(aHeader, KEY_SKY_RES, KEY_SKY_RES_COMMENT);
+                                       fabs(aProperties->skyres));
+
+  const char *method_qualifier = (aProperties->skyres < 0.) ?
+      "default" : "measured";
+  char *comment = cpl_sprintf(KEY_SKY_RES_COMMENT " (%s)", method_qualifier);
+  cpl_propertylist_set_comment(aHeader, KEY_SKY_RES, comment);
+  cpl_free(comment);
+
   cpl_propertylist_insert_after_double(aHeader, KEY_SKY_RES, KEY_SKY_RERR,
-                                       aProperties->skyrerr);
-  cpl_propertylist_set_comment(aHeader, KEY_SKY_RERR, KEY_SKY_RERR_COMMENT);
+                                       fabs(aProperties->skyrerr));
+
+  method_qualifier = (aProperties->skyrerr < 0.) ? "default" : "measured";
+  comment = cpl_sprintf(KEY_SKY_RERR_COMMENT " (%s)", method_qualifier);
+  cpl_propertylist_set_comment(aHeader, KEY_SKY_RERR, comment);
+  cpl_free(comment);
+
   cpl_propertylist_insert_after_double(aHeader, KEY_SKY_RERR, KEY_PIXNOISE,
                                        aProperties->pixnoise);
   cpl_propertylist_set_comment(aHeader, KEY_PIXNOISE, KEY_PIXNOISE_COMMENT);
