@@ -47,10 +47,10 @@ static const double kVLTArea = 483250.7024654051; /* [cm**2] */
  * C source files and linking will otherwise not work.                        *
  *----------------------------------------------------------------------------*/
 /* nominal sizes of MUSE spaxels in both WFM and NFM */
-static const double kMuseSpaxelSizeX_WFM = 0.2;
-static const double kMuseSpaxelSizeY_WFM = 0.2;
-static const double kMuseSpaxelSizeX_NFM = 0.02534;
-static const double kMuseSpaxelSizeY_NFM = 0.02534;
+static const double kMuseSpaxelSizeX_WFM = 0.2; /* as defined by the...      */
+static const double kMuseSpaxelSizeY_WFM = 0.2; /* ... geometry table pixels */
+static const double kMuseSpaxelSizeX_NFM = 0.02519; /* computed from NFM ... */
+static const double kMuseSpaxelSizeY_NFM = 0.02542; /* astrometric fields    */
 
 /* Expected average FWHM [pix] of a point-like lamp emission line on the CCD */
 static const double kMuseAverageFWHM_x = 1.6;
