@@ -69,6 +69,8 @@ muse_lsf_cube **muse_lsf_cube_load_all(muse_processing *aProcessing);
 void muse_lsf_cube_delete_all(muse_lsf_cube **lsf);
 
 cpl_error_code muse_lsf_apply(const cpl_image *, const muse_wcs *, cpl_array *, double);
+cpl_error_code muse_lsf_apply_slice(muse_pixtable *, double, double aFlux,
+                                    cpl_image *, muse_wcs *);
 cpl_image *muse_lsf_average_cube_all(muse_lsf_cube **, muse_pixtable *);
 muse_wcs *muse_lsf_cube_get_wcs_all(muse_lsf_cube **);
 cpl_error_code muse_lsf_fold_rectangle(cpl_image *, const muse_wcs *, double);
