@@ -2,7 +2,7 @@
 /* vim:set sw=2 sts=2 et cin: */
 /*
  * This file is part of the MUSE Instrument Pipeline
- * Copyright (C) 2013 European Southern Observatory
+ * Copyright (C) 2013,2018 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -144,11 +144,8 @@ muse_mask_save(muse_mask *aMask, const char *aFilename)
 {
   cpl_ensure_code(aMask && aFilename, CPL_ERROR_NULL_INPUT);
 
-  cpl_image *image = cpl_image_new_from_mask(aMask->mask);
-  cpl_error_code err = cpl_image_save(image, aFilename, CPL_TYPE_UNSPECIFIED,
-                                      aMask->header, CPL_IO_CREATE);
-  cpl_image_delete(image);
-
+  cpl_error_code err = cpl_mask_save(aMask->mask, aFilename, aMask->header,
+                                     CPL_IO_CREATE);
   if (err != CPL_ERROR_NONE) {
     cpl_msg_error(__func__, "Could not save mask %s: %s",
                   aFilename, cpl_error_get_message());
