@@ -1407,8 +1407,8 @@ muse_postproc_process_exposure(muse_postproc_properties *aProp,
     muse_wcs_object *wcs = muse_wcs_object_new();
     wcs->crpix1 = aProp->crpix1; /* set center of rotation */
     wcs->crpix2 = aProp->crpix2;
-    rc = muse_wcs_locate_sources(pt, fabsf(aProp->detsigma), aProp->centroid,
-                                 wcs);
+    rc = muse_wcs_locate_sources(pt, fabsf((float)aProp->detsigma),
+                                 aProp->centroid, wcs);
     if (aProp->detsigma < 0.) {
       /* loop through possible detection sigmas to find the optimal solution */
       rc = muse_wcs_optimize_solution(wcs, aProp->detsigma, aProp->centroid,
@@ -1535,11 +1535,11 @@ muse_postproc_offsets_scale(muse_pixtable *aPT, const cpl_table *aOffsets,
       }
       cpl_propertylist_set_comment(aPT->header, "DEC", "offset applied!");
       /* store in the header of the pixel table */
-      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DRA, 1);
+      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DRA, 1U);
       snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DRA_C, offsets[0] * 3600.);
       cpl_propertylist_append_double(aPT->header, keyword, offsets[0]);
       cpl_propertylist_set_comment(aPT->header, keyword, comment);
-      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DDEC, 1);
+      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DDEC, 1U);
       snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DDEC_C, offsets[1] * 3600.);
       cpl_propertylist_append_double(aPT->header, keyword, offsets[1]);
       cpl_propertylist_set_comment(aPT->header, keyword, comment);
@@ -1549,13 +1549,13 @@ muse_postproc_offsets_scale(muse_pixtable *aPT, const cpl_table *aOffsets,
       cpl_msg_debug(__func__, "Scaling flux of exposure by %g.", offsets[2]);
       muse_pixtable_flux_multiply(aPT, offsets[2]);
       /* store in the header of the pixel table */
-      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_FLUX_SCALEi, 1);
+      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_FLUX_SCALEi, 1U);
       cpl_propertylist_append_double(aPT->header, keyword, offsets[2]);
       cpl_propertylist_set_comment(aPT->header, keyword, MUSE_HDR_FLUX_SCALEi_C);
     } /* if scale */
     /* store date of changed exposure in the header of the output pixel table */
-    snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS, 1);
-    snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS_C, 1);
+    snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS, 1U);
+    snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS_C, 1U);
     cpl_propertylist_append_string(aPT->header, keyword,
                                    muse_pfits_get_dateobs(aPT->header));
     cpl_propertylist_set_comment(aPT->header, keyword, comment);
