@@ -731,11 +731,20 @@ muse_quality_merge_badpix(cpl_table *aTable, const cpl_table *aToMerge)
     if (x[i] == x[i-1] && y[i] == y[i-1]) {
       dq[i-1] |= dq[i]; /* merge Euro3D status flags */
       if (value) {
-        /* as we know nothing else, use the maximum for the value */
-        value[i-1] = fmax(value[i-1], value[i]);
-      }
+        /* as we know nothing else, use the maximum for the value, *
+         * but only if both values are valid                       */
+        cpl_boolean v1 = cpl_table_is_valid(aTable, MUSE_BADPIX_VALUE, i-1),
+                    v2 = cpl_table_is_valid(aTable, MUSE_BADPIX_VALUE, i);
+        if (v1 && v2) {
+          value[i-1] = fmax(value[i-1], value[i]);
+        } else if (v2) { /* if v1, then nothing needs to be done */
+          value[i-1] = value[i];
+        } else if (!v1 && !v2) { /* neither is valid! */
+          cpl_table_set_invalid(aTable, MUSE_BADPIX_VALUE, i-1);
+        }
+      } /* if value */
       cpl_table_select_row(aTable, i);
-    }
+    } /* if same coordinates */
   } /* for i (all table rows) */
   rc = cpl_table_erase_selected(aTable);
 
