@@ -1457,7 +1457,7 @@ muse_trace_table_get_polys_for_slice(const cpl_table *aTable,
  */
 /*---------------------------------------------------------------------------*/
 void
-muse_trace_polys_delete(cpl_polynomial *aPolys[])
+muse_trace_polys_delete(cpl_polynomial **aPolys)
 {
   if (!aPolys) {
     return;
