@@ -46,7 +46,7 @@
   this list is mostly taken from the FITS Standard v3.0 (Tab. 8.2, p. 77).
  */
 #define MUSE_WCS_KEYS  "^C(TYPE|UNIT|RPIX|RVAL|DELT|SYER|RDER)|^CD[0-9]+_[0-9]+|" \
-                       "^WCSAXES$|^L[OA][NT]POLE$"
+                       "^WCSAXES[ A-Z]|^WCSNAME[ A-Z]|^L[OA][NT]POLE$"
 /**
   @brief   name for special astrometry detection image
 
@@ -54,6 +54,7 @@
   astrometric field.
  */
 #define MUSE_WCS_DETIMAGE_EXTNAME "ASTROMETRY_DETECTION"
+#define MUSE_WCS_SOURCE_TABLE_NAME "ASTROMETRY_SOURCES"
 
 /*----------------------------------------------------------------------------*
  *                          Special variable types                            *
@@ -281,4 +282,6 @@ cpl_error_code muse_wcs_get_scales(cpl_propertylist *, double *, double *);
 
 muse_wcs *muse_wcs_new(cpl_propertylist *);
 
+cpl_error_code muse_wcs_copy_keywords(const cpl_propertylist *, cpl_propertylist *, char, const char *);
+
 #endif /* MUSE_WCS_H */
