@@ -34,6 +34,7 @@
 #include "muse_pfits.h"
 #include "muse_wcs.h"
 #include "muse_utils.h"
+#include "muse_rtcdata.h"
 #include "muse_data_format_z.h"
 
 /*----------------------------------------------------------------------------*/
@@ -166,6 +167,74 @@ muse_xcombine_weights_infotable(muse_pixtable **aPixtables)
   return table;
 } /* muse_xcombine_weights_infotable() */
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief   Calculate the weighted mean RTC Strehl ratio of a set of exposures.
+  @param   aPixtables Input pixel tables containing the individual Strehl
+                      ratios.
+  @param   aStrehl    The computed weighted mean Strehl ratio of the combined
+                      exposure.
+  @param   aStrehlErr The error of the weighted mean Strehl ratio.
+  @return  CPL_ERROR_NONE on success, or an appropriate CPL error code
+
+  Reads the RTC Strehl ratio and its associated uncertainty from the header
+  (from the keywords defined by the symbols @c MUSE_HDR_RTC_STREHL and
+  @c MUSE_HDR_RTC_STREHLERR) of the individual exposures, e.g. the individual
+  input pixel tables @em aPixtables. The weighted mean of the individual
+  Strehl ratios is computed, together with its propagated error. The results
+  are stored in @em aStrehl and @em aStrehlErr.
+
+  The function expects that the input list of pixel tables @em aPixtables is
+  @c NULL terminated. Processing of pixel tables stops at the first @NULL
+  element.
+ */
+/*----------------------------------------------------------------------------*/
+static cpl_error_code
+muse_xcombine_get_mean_strehl(muse_pixtable *const *const aPixtables,
+                              double *aStrehl, double *aStrehlErr)
+{
+  double wstrehl = 0.;
+  double wtotal = 0.;
+
+  /* Count the pixel tables in the input list. */
+  unsigned int npt = 0;
+  while (aPixtables[npt]) {
+    ++npt;
+  }
+
+  /* Calculate the weighted mean of the Strehl ratios measured for each    *
+   * of the exposures, together with its error. The results are propagated *
+   * by updating the MUSE.DRS.STREHL and MUSE.DRS.STREHERR keywords.       */
+  unsigned int nskipped = 0;
+  unsigned int ipt;
+  for (ipt = 0; ipt < npt; ++ipt) {
+    cpl_errorstate estate = cpl_errorstate_get();
+    double svalue = cpl_propertylist_get_double(aPixtables[ipt]->header,
+                                                MUSE_HDR_RTC_STREHL);
+    double serror = cpl_propertylist_get_double(aPixtables[ipt]->header,
+                                                MUSE_HDR_RTC_STREHLERR);
+    if (cpl_errorstate_is_equal(estate)) {
+      double weight = 1. / (serror * serror);
+      wstrehl += weight * svalue;
+      wtotal += weight;
+    } else {
+      /* If the keywords are not found, just reset the error state. The *
+       * missing keywords are implicitly recorded as invalid array      *
+       * elements which will be handled later.                          */
+      cpl_errorstate_set(estate);
+      cpl_msg_warning(__func__, "Exposure %d does not provide RTC Strehl "
+                      "measurements, skipping this one!", ipt + 1);
+      ++nskipped;
+    }
+  }
+  if (nskipped >= npt) {
+    return CPL_ERROR_DATA_NOT_FOUND;
+  }
+  *aStrehl = wstrehl / wtotal;
+  *aStrehlErr = 1. / sqrt(wtotal);
+  return CPL_ERROR_NONE;
+} /* muse_xcombine_get_mean_strehl() */
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief   compute the weights for combination of two or more exposures
@@ -467,8 +536,10 @@ muse_xcombine_tables(muse_pixtable **aPixtables, const cpl_table *aOffsets)
   double timeinit = cpl_test_get_walltime(),
          cpuinit = cpl_test_get_cputime();
   muse_utils_memory_dump("muse_xcombine_tables() start");
+
+  /* The first pixel table in the list is used as the result. *
+   * All other pixel tables will be appended.                 */
   muse_pixtable *pt = aPixtables[0];
-  aPixtables[0] = NULL;
   /* warn, if the table was not RV corrected */
   if (!muse_pixtable_is_rvcorr(pt)) {
     cpl_msg_warning(__func__, "Data of exposure 1 (DATE-OBS=%s) was not radial-"
@@ -478,14 +549,14 @@ muse_xcombine_tables(muse_pixtable **aPixtables, const cpl_table *aOffsets)
   muse_pixtable_origin_copy_offsets(pt, NULL, 1);
   /* add exposure range */
   char keyword[KEYWORD_LENGTH], comment[KEYWORD_LENGTH];
-  snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_PT_EXP_FST, 1);
+  snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_PT_EXP_FST, 1U);
   cpl_propertylist_append_long_long(pt->header, keyword, 0);
-  snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_PT_EXP_FST_COMMENT, 1);
+  snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_PT_EXP_FST_COMMENT, 1U);
   cpl_propertylist_set_comment(pt->header, keyword, comment);
-  snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_PT_EXP_LST, 1);
+  snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_PT_EXP_LST, 1U);
   cpl_propertylist_append_long_long(pt->header, keyword,
                                     muse_pixtable_get_nrow(pt) - 1);
-  snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_PT_EXP_LST_COMMENT, 1);
+  snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_PT_EXP_LST_COMMENT, 1U);
   cpl_propertylist_set_comment(pt->header, keyword, comment);
 
   double ra0 =  muse_pfits_get_ra(pt->header),
@@ -501,11 +572,11 @@ muse_xcombine_tables(muse_pixtable **aPixtables, const cpl_table *aOffsets)
       cpl_msg_debug(__func__, "Applying coordinate offsets to exposure 1: %e/%e"
                     " deg", offsets[0], offsets[1]);
       /* store in the header of the output pixel table */
-      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DRA, 1);
+      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DRA, 1U);
       snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DRA_C, offsets[0] * 3600.);
       cpl_propertylist_append_double(pt->header, keyword, offsets[0]);
       cpl_propertylist_set_comment(pt->header, keyword, comment);
-      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DDEC, 1);
+      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DDEC, 1U);
       snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DDEC_C, offsets[1] * 3600.);
       cpl_propertylist_append_double(pt->header, keyword, offsets[1]);
       cpl_propertylist_set_comment(pt->header, keyword, comment);
@@ -515,13 +586,13 @@ muse_xcombine_tables(muse_pixtable **aPixtables, const cpl_table *aOffsets)
       cpl_msg_debug(__func__, "Scaling flux of exposure 1 by %g.", offsets[2]);
       muse_pixtable_flux_multiply(pt, offsets[2]);
       /* store in the header of the output pixel table */
-      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_FLUX_SCALEi, 1);
+      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_FLUX_SCALEi, 1U);
       cpl_propertylist_append_double(pt->header, keyword, offsets[2]);
       cpl_propertylist_set_comment(pt->header, keyword, MUSE_HDR_FLUX_SCALEi_C);
     } /* if scale */
     /* store date of changed exposure in the header of the output pixel table */
-    snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS, 1);
-    snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS_C, 1);
+    snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS, 1U);
+    snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS_C, 1U);
     cpl_propertylist_append_string(pt->header, keyword,
                                    muse_pfits_get_dateobs(pt->header));
     cpl_propertylist_set_comment(pt->header, keyword, comment);
@@ -529,6 +600,46 @@ muse_xcombine_tables(muse_pixtable **aPixtables, const cpl_table *aOffsets)
   cpl_free(offsets);
   muse_wcs_position_celestial(pt, ra0, dec0);
 
+  /* Calculate the weighted mean RTC Strehl ratio for the set of     *
+   * exposures. It is needed to calculate IDP performance indicators *
+   * later on. It is only calculated for NFM observations. The mode  *
+   * check is done on the first exposure in the input list, assuming *
+   * consistency!                                                    *
+   * The results are written to the header of the combined exposure, *
+   * i.e. the header of the first exposure.                          */
+  muse_ins_mode mode = muse_pfits_get_mode(pt->header);
+  if (mode == MUSE_MODE_NFM_AO_N) {
+    double rtc_strehl = 0.;
+    double rtc_strehlerr = 0.;
+    cpl_error_code ecode = muse_xcombine_get_mean_strehl(aPixtables,
+                                                         &rtc_strehl,
+                                                         &rtc_strehlerr);
+    if (ecode != CPL_ERROR_NONE) {
+      cpl_msg_warning(__func__, "Could not compute the mean RTC Strehl ratio "
+                      "for the combined exposure!");
+      /* Make sure we do not propagate any keywords on failure */
+      cpl_propertylist_erase(pt->header, MUSE_HDR_RTC_STREHL);
+      cpl_propertylist_erase(pt->header, MUSE_HDR_RTC_STREHLERR);
+    } else {
+      /* Propagate the weighted mean Strehl ratio and its uncertainty */
+      cpl_propertylist_update_double(pt->header, MUSE_HDR_RTC_STREHL,
+                                     rtc_strehl);
+      cpl_propertylist_set_comment(pt->header, MUSE_HDR_RTC_STREHL,
+                                   "Weighted mean RTC Strehl ratio of the "
+                                   "combined exposure.");
+      cpl_propertylist_update_double(pt->header, MUSE_HDR_RTC_STREHLERR,
+                                     rtc_strehlerr);
+      cpl_propertylist_set_comment(pt->header, MUSE_HDR_RTC_STREHLERR,
+                                   "Error of the weighted mean RTC Strehl "
+                                   "ratio.");
+    }
+  }
+
+  /* Remove the first pixel table from the input list. It is now used as *
+   * the result pixel table. Cannot be done earlier because the Strehl   *
+   * computation needs the complete list of input pixel tables!          */
+  aPixtables[0] = NULL;
+
   unsigned int i, nskipped = 0;
   for (i = 1; i < npt; i++) {
     if (muse_pixtable_wcs_check(aPixtables[i]) != MUSE_PIXTABLE_WCS_NATSPH) {
