@@ -70,6 +70,12 @@ muse_astrometry_compute(muse_processing *aProcessing,
   prop->detsigma = aParams->detsigma;
   prop->radius = aParams->radius;
   prop->faccuracy = aParams->faccuracy;
+  if (prop->faccuracy < 0) {
+    cpl_msg_error(__func__, "Negative facurracy. Use positive values, or zero to switch "
+                  "to the quadruple based method.");
+    muse_postproc_properties_delete(prop);
+    return -1;
+  }
   prop->rejsigma = aParams->rejsigma;
   prop->niter = aParams->niter;
   prop->centroid = MUSE_WCS_CENTROID_GAUSSIAN;
@@ -137,8 +143,6 @@ muse_astrometry_compute(muse_processing *aProcessing,
   } /* for i (exposures) */
   muse_postproc_properties_delete(prop);
 
-  /* XXX now combine the possibly more than one astrometric WCSs?! */
-
   for (i = 0; i < nexposures; i++) {
     /* convert DQ to NANs, do QC, then save cube; *
      * it already contains the images             */
@@ -152,19 +156,36 @@ muse_astrometry_compute(muse_processing *aProcessing,
                                cpl_propertylist_get_string(wcsobjs[i]->cube->header,
                                                            "OBJECT"));
     cpl_propertylist_update_string(wcsobjs[i]->wcs, "OBJECT", object);
+    cpl_free(object);
+    /* try to save the bare header with the solution at least */
     cpl_error_code rc = muse_processing_save_header(aProcessing, -1,
                                                     wcsobjs[i]->wcs,
                                                     MUSE_TAG_ASTROMETRY_WCS);
-    cpl_free(object);
     if (rc != CPL_ERROR_NONE) {
-      cpl_msg_warning(__func__, "Failed to save %s for exposure %d: %s",
+      cpl_msg_warning(__func__, "Failed to save %s for exposure %d (header): %s",
                       MUSE_TAG_ASTROMETRY_WCS, i+1, cpl_error_get_message());
-    } /* if */
-
-    /* XXX add option to create cube using the derived calibration *
-     *     curve to check quality of the computed astrometry       */
+    } else {
+      /* Since saving the table directly with the WCS as primary header    *
+       * erases the WCS keywords, manually append the table to the file.   *
+       * For that, find the filename to use (from the last frame in the    *
+       * output frameset) and then save the table to a new FITS extension. */
+      int nf = cpl_frameset_get_size(aProcessing->outframes);
+      cpl_frame *f = cpl_frameset_get_position(aProcessing->outframes, nf - 1);
+      const char *fn = cpl_frame_get_filename(f);
+      cpl_propertylist *header = cpl_propertylist_new();
+      cpl_propertylist_append_string(header, "EXTNAME",
+                                     MUSE_WCS_SOURCE_TABLE_NAME);
+      rc = cpl_table_save(wcsobjs[i]->detected, NULL, header, fn, CPL_IO_EXTEND);
+      cpl_propertylist_delete(header);
+      if (rc != CPL_ERROR_NONE) {
+        cpl_msg_warning(__func__, "Failed to save %s for exposure %d (table): %s",
+                        MUSE_TAG_ASTROMETRY_WCS, i+1, cpl_error_get_message());
+      } else {
+        cpl_msg_info(__func__, "Appended %s to \"%s\".", MUSE_WCS_SOURCE_TABLE_NAME, fn);
+      } /* else */
+    } /* else */
     muse_wcs_object_delete(wcsobjs[i]);
-  }
+  } /* for i (exposures) */
   cpl_free(wcsobjs);
 
   return cpl_errorstate_is_equal(state) ? 0 : -1;
