@@ -283,7 +283,7 @@ muse_twilight_reconstruct(muse_processing *aProcessing,
     if (nifu == 24 &&
         muse_pfits_get_mode(pts[nifu - 1]->header) == MUSE_MODE_NFM_AO_N) {
       /* CHAN24 in NFM is vignetted, special handling */
-      kw = cpl_sprintf(MUSE_HDR_FLAT_FLUX_SKY"%hhu", 23);
+      kw = cpl_sprintf(MUSE_HDR_FLAT_FLUX_SKY"%d", 23);
       double flux23 = cpl_propertylist_get_double(pt->header, kw);
       cpl_free(kw);
       cpl_msg_debug(__func__, "NFM: using flux (%.3g) from CHAN23 for "
