@@ -19,6 +19,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
+#define _DEFAULT_SOURCE
 #define _BSD_SOURCE /* get mkdtemp() from stdlib.h */
 #include <stdlib.h>
 #include <sys/types.h>
@@ -132,6 +133,7 @@ muse_test_pixtable_create_exptable(const char *aDir, cpl_table *aFFSpec)
                                      5500.);
   pt->header = cpl_propertylist_new();
   cpl_propertylist_append_string(pt->header, MUSE_HDR_PT_TYPE, MUSE_PIXTABLE_STRING_FULL);
+  cpl_propertylist_append_string(pt->header, "ESO INS MODE", "WFM-NOAO-N");
   if (aFFSpec) {
     pt->ffspec = cpl_table_duplicate(aFFSpec);
   }
@@ -1013,6 +1015,17 @@ int main(int argc, char **argv)
   cpl_test_nonnull(pt2);
   /* compare first and last entry of the data column to be sure */
   muse_test_pixtable_compare(pt, pt2);
+  /* and with ffspec table */
+  pt2->ffspec = cpl_table_new(5);
+  ps = cpl_errorstate_get();
+  muse_pixtable *pt2ff = muse_pixtable_duplicate(pt2);
+  cpl_test(cpl_errorstate_is_equal(ps));
+  cpl_test_nonnull(pt2ff);
+  cpl_test_nonnull(pt2ff->ffspec);
+  cpl_test_eq(cpl_table_get_nrow(pt2ff->ffspec), 5);
+  muse_pixtable_delete(pt2ff);
+  cpl_table_delete(pt2->ffspec);
+  pt2->ffspec = NULL;
   muse_pixtable *pt2keep = muse_pixtable_duplicate(pt2);
 
   /* do the following tests twice:                               *
