@@ -19,6 +19,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
+#define _DEFAULT_SOURCE
 #define _BSD_SOURCE /* get setenv() from stdlib.h */
 #include <stdlib.h> /* setenv() */
 #include <string.h>
@@ -657,7 +658,6 @@ muse_test_resampling_cube(muse_pixtable *aPtPix)
 #if 0
           cpl_msg_debug("blablabla", "%d -> %d", next, next2);
           system(sys);
-          cpl_free(sys);
 #endif
           cpl_test_eq(next2, next + 1); /* one more extension now */
           muse_datacube *cubel = muse_datacube_load(fn2);
@@ -666,11 +666,30 @@ muse_test_resampling_cube(muse_pixtable *aPtPix)
           cpl_test_nonnull(cubel->stat);
           cpl_test_eq(cpl_array_get_size(cubel->recnames), 2);
           cpl_test_eq(muse_imagelist_get_size(cubel->recimages), 2);
-          muse_datacube_delete(cubel);
+#if MUSE_TEST_RESAMPLING_DELETE_FILES
+          cpl_test(remove(fn2) == 0); /* delete the file again */
+#endif
+          /* move one image in the list, so that a NULL entry appears */
+          muse_image *imdum = muse_imagelist_unset(cubel->recimages, 1);
+          muse_imagelist_set(cubel->recimages, imdum, 2);
+          cpl_array_set_size(cubel->recnames, 3);
+          cpl_array_set_string(cubel->recnames, 1, "NULL");
+          cpl_array_set_string(cubel->recnames, 2, "DUPLICATE");
+          cpl_test(muse_datacube_save(cubel, fn2) == CPL_ERROR_NONE);
+          next2 = cpl_fits_count_extensions(fn2);
+          cpl_test_eq(next2, next + 1); /* one (but only one!) more extension */
+          cpl_test_eq(cpl_fits_find_extension(fn2, "white"), 3);
+          cpl_test_eq(cpl_fits_find_extension(fn2, "DUPLICATE"), 4);
+#if 0
+          cpl_msg_debug("blabla3", "%d -> %d", next, next2);
+          system(sys);
+          cpl_free(sys);
+#endif
 #if MUSE_TEST_RESAMPLING_DELETE_FILES
           cpl_test(remove(fn2) == 0); /* delete the file again */
 #endif
           cpl_free(fn2);
+          muse_datacube_delete(cubel);
 
           /* test failure cases */
           state = cpl_errorstate_get();
@@ -722,6 +741,19 @@ muse_test_resampling_cube(muse_pixtable *aPtPix)
   cube = muse_resampling_cube(aPtPix, params, NULL);
   cpl_test_null(cube);
   cpl_errorstate_set(ps);
+  /* case of pixel table without rows */
+  params->method = MUSE_RESAMPLE_WEIGHTED_DRIZZLE;
+  muse_pixtable *ptempty = muse_pixtable_duplicate(aPtPix);
+  cpl_table_set_size(ptempty->table, 0);
+  grid = (void *)222; /* something non-NULL */
+  ps = cpl_errorstate_get();
+  cube = muse_resampling_cube(ptempty, params, &grid);
+  cpl_test(!cpl_errorstate_is_equal(ps) &&
+           cpl_error_get_code() == CPL_ERROR_DATA_NOT_FOUND);
+  cpl_errorstate_set(ps);
+  cpl_test_null(cube);
+  cpl_test_null(grid);
+  muse_pixtable_delete(ptempty);
   /* for Euro3D */
   params->method = MUSE_RESAMPLE_NEAREST;
   muse_euro3dcube *e3d = muse_resampling_euro3d(NULL, params);
