@@ -42,6 +42,9 @@
  *     comma-separated filter names (EXTNAMEs) to load from FILTER_LIST;
  *     by default all table extensions of FILTER_LIST are used to reconstruct
  *     images
+ *   - <tt>-l</tt> (optional)\n
+ *     give wavelength range (with two extra numerical arguments) to create
+ *     an ad-hoc filter
  *   - <tt><b>CUBE</b></tt>\n
  *     the filename of the MUSE cube to use
  *   - <tt><b>FILTER_LIST</b></tt>\n
@@ -52,17 +55,19 @@
  *   - <tt> 0</tt>\n   Success
  *   - <tt> 1</tt>\n   less than two filenames given
  *   - <tt> 2</tt>\n   argument <tt>-f</tt> given without filter names
+ *   - <tt> 3</tt>\n   argument <tt>-l</tt> given without wavelength values
  *   - <tt> 9</tt>\n   unknown option given
  *   - <tt>10</tt>\n   either CUBE or FILTER_LIST filenames are missing
  *   - <tt>11</tt>\n   CUBE could not be loaded from file
+ *   - <tt>12</tt>\n   illegal wavelength range given
  */
 /*----------------------------------------------------------------------------*/
 
 /**@{*/
 
 #define PRINT_USAGE(rc)                                                        \
-  fprintf(stderr, "Usage: %s [ -x ] [ -f filter,names ] CUBE FILTER_LIST\n",   \
-          argv[0]);                                                            \
+  fprintf(stderr, "Usage: %s [ -x ] [ -f filter,names ] [ -l <lambda1> <lambda"\
+          "2> ] CUBE FILTER_LIST\n", argv[0]);                                                            \
   cpl_end(); return (rc);
 
 int main(int argc, char **argv)
@@ -83,6 +88,8 @@ int main(int argc, char **argv)
   cpl_array *filters = NULL; /* filter names */
   char *iname = NULL, /* input name */
        *list = NULL; /* filter list names */
+  double lambda1 = NAN,
+         lambda2 = NAN;
   cpl_boolean extended = CPL_FALSE;
   int i;
 
@@ -98,6 +105,14 @@ int main(int argc, char **argv)
       }
     } else if (strncmp(argv[i], "-x", 3) == 0) {
       extended = CPL_TRUE;
+    } else if (strncmp(argv[i], "-l", 3) == 0) {
+      /* skip to next arg to get start value */
+      if (i+2 < argc) {
+        lambda1 = atof(argv[++i]);
+        lambda2 = atof(argv[++i]);
+      } else {
+        PRINT_USAGE(3);
+      }
     } else if (strncmp(argv[i], "-", 1) == 0) { /* unallowed options */
       PRINT_USAGE(9);
     } else {
@@ -138,6 +153,38 @@ int main(int argc, char **argv)
     } while (cpl_errorstate_is_equal(es));
     cpl_errorstate_set(es);
   } /* if no filters given */
+
+  muse_table *fcustom = NULL;
+  if (isnan(lambda1) && isnan(lambda2)) {
+    /* do nothing, this is expected if the -l parameter was not used! */
+  } else if (!isfinite(lambda1) || !isfinite(lambda2) || lambda1 >= lambda2) {
+    cpl_msg_error(idstring, "Bad wavelength range given %f ... %f Angstrom!",
+                  lambda1, lambda2);
+    cpl_array_delete(filters);
+    PRINT_USAGE(12); /* better stop, before time is spent to load the cube */
+  } else {
+    /* add custom filter */
+    char *fname = cpl_sprintf("CUSTOM_%.3f_%.3f", lambda1, lambda2);
+    cpl_array_set_size(filters, cpl_array_get_size(filters) + 1);
+    cpl_array_set_string(filters, cpl_array_get_size(filters) - 1, fname);
+    /* create ad-hoc filter, using minimal rectangular filter function table */
+    extern const muse_cpltable_def muse_filtertable_def[];
+    cpl_table *ftable = muse_cpltable_new(muse_filtertable_def, 4);
+    cpl_table_set(ftable, "lambda", 0, lambda1 - 1e-5);
+    cpl_table_set(ftable, "lambda", 1, lambda1);
+    cpl_table_set(ftable, "lambda", 2, lambda2);
+    cpl_table_set(ftable, "lambda", 3, lambda2 + 1e-5);
+    cpl_table_set(ftable, "throughput", 0, 0.);
+    cpl_table_set(ftable, "throughput", 1, 1.);
+    cpl_table_set(ftable, "throughput", 2, 1.);
+    cpl_table_set(ftable, "throughput", 3, 0.);
+    /* now convert into MUSE table with header */
+    fcustom = muse_table_new();
+    fcustom->table = ftable;
+    fcustom->header = cpl_propertylist_new();
+    cpl_propertylist_append_string(fcustom->header, "EXTNAME", fname);
+    cpl_free(fname);
+  } /* else: valid wavelengths */
 #if 0
   cpl_array_dump(filters, 0, 10000, stdout);
   fflush(stdout);
@@ -162,7 +209,7 @@ int main(int argc, char **argv)
   for (i = 0, idx = 0; i < n; i++) {
     const char *fname = cpl_array_get_string(filters, i);
     muse_table *ftable = NULL;
-    if (fname && strncmp(fname, "white", 6)) {
+    if (fname && strncmp(fname, "white", 6) && strncmp(fname, "CUSTOM_", 7)) {
       iext = cpl_fits_find_extension(list, fname);
       if (iext < 1) {
         cpl_msg_warning(idstring, "No filter \"%s\" found in table \"%s\"", fname,
@@ -178,6 +225,10 @@ int main(int argc, char **argv)
       cpl_propertylist_copy_property_regexp(ftable->header, hext,
                                             "^EXTNAME$|^Z|^COMMENT", 0);
       cpl_propertylist_delete(hext);
+    } else if (fname && !strncmp(fname, "CUSTOM_", 7)) {
+      cpl_msg_info(idstring, "Integrating over \"%s\" filter (wavelength range "
+                   "%.3f ... %.3f Angstrom)", fname, lambda1, lambda2);
+      ftable = fcustom;
     } else {
       cpl_msg_info(idstring, "Integrating over filter \"%s\" (builtin)", fname);
       ftable = muse_table_load_filter(NULL, fname);
